<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="57"/>
        <source>Exit Miracast</source>
        <translation>退出投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>正在投屏，投屏過程中請勿退出影院。</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="102"/>
        <source>Display device</source>
        <translation>投屏設備</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="67"/>
        <source>Project to</source>
        <translation>投屏到</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="336"/>
        <source>Searching for devices...</source>
        <translation>正在查找設備...</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="345"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>暫無可投屏設備，請確保所投屏設備和您的電腦連接同一無線網絡</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="477"/>
        <location filename="../src/main.cpp" line="181"/>
        <location filename="../src/main.cpp" line="219"/>
        <location filename="../src/widgets/volumeslider.cpp" line="113"/>
        <location filename="../src/widgets/platform/platform_volumeslider.cpp" line="116"/>
        <location filename="../src/common/volumemonitoring.cpp" line="68"/>
        <location filename="../src/common/dmr_settings.cpp" line="192"/>
        <source>Movie</source>
        <translation>電影</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="182"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>電影是一款支持多種影片格式本地播放和流媒體播放的影片播放器。</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="186"/>
        <location filename="../src/common/settings_translation.cpp" line="59"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="189"/>
        <location filename="../src/common/settings_translation.cpp" line="57"/>
        <source>Help</source>
        <translation>協助</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="194"/>
        <location filename="../src/common/settings_translation.cpp" line="58"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="10"/>
        <source>Auto add similar files to play</source>
        <translation>自動查找相似文件連續播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="11"/>
        <source>Clear playlist when exit</source>
        <translation>退出影院時清空播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Show thumbnails in progress bar</source>
        <translation>進度條顯示為膠片樣式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Show video preview on mouseover</source>
        <translation>鼠標懸停進度條時顯示預覽</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Open a new player for each file played</source>
        <translation>允許同時運行多個影院</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Pause when minimized</source>
        <translation>最小化時暫停</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Remember playback position</source>
        <translation>記錄播放時間</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Default play mode</source>
        <translation>默認播放模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Path</source>
        <translation>保存路徑</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Basic</source>
        <translation>基本</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <location filename="../src/common/settings_translation.cpp" line="26"/>
        <source>Screenshot</source>
        <translation>截圖設定</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <source>File</source>
        <translation>檔</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Frame/Sound</source>
        <translation>影格/聲音</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>Playback</source>
        <translation>播放設定</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <location filename="../src/common/settings_translation.cpp" line="28"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <source>Font Style</source>
        <translation>字體樣式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Restore Defaults</source>
        <translation>恢復默認</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Open file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Open next</source>
        <translation>開啟下一個</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open previous</source>
        <translation>開啟上一個</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Mini mode</source>
        <translation>精簡模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Next frame</source>
        <translation>下一幀</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Previous frame</source>
        <translation>上一幀</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Volume down</source>
        <translation>調低音量</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Volume up</source>
        <translation>調高音量</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Speed up</source>
        <translation>加速播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Speed down</source>
        <translation>减速播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Pause/Play</source>
        <translation>暫停/播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Reset speed</source>
        <translation>還原播放速度</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Delete from playlist</source>
        <translation>從播放列表刪除</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Film info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Rewind</source>
        <translation>後退</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Forward</source>
        <translation>快進</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Burst shooting</source>
        <translation>連拍截圖</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Film screenshot</source>
        <translation>影片截圖</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>0.5s backward</source>
        <translation>字幕延遲0.5秒</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>0.5s forward</source>
        <translation>字幕提前0.5秒</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>Font</source>
        <translation>字體</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>退出全屏/迷你模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <source>Decoding</source>
        <translation>解碼方式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <source>Auto select (Recommended)</source>
        <translation>自動選擇（推薦）</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Hardware decoding</source>
        <translation>硬件解碼</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Software decoding</source>
        <translation>軟件解碼</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="201"/>
        <location filename="../src/common/mainwindow.cpp" line="203"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>此文件夾沒有操作權限</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="203"/>
        <location filename="../src/common/mainwindow.cpp" line="205"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="219"/>
        <location filename="../src/common/mainwindow.cpp" line="221"/>
        <source>Invalid folder</source>
        <translation>此文件夾無效</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="239"/>
        <location filename="../src/common/mainwindow.cpp" line="241"/>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2906"/>
        <location filename="../src/common/mainwindow.cpp" line="2875"/>
        <source>Network disconnected</source>
        <translation>網絡已斷開</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="17"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="18"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="22"/>
        <source>Please enter the URL:</source>
        <translation>請輸入您要播放文件的網絡地址：</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="53"/>
        <location filename="../src/common/actions.cpp" line="127"/>
        <location filename="../src/common/actions.cpp" line="314"/>
        <source>Open file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="55"/>
        <location filename="../src/common/actions.cpp" line="128"/>
        <location filename="../src/common/actions.cpp" line="315"/>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="56"/>
        <location filename="../src/common/actions.cpp" line="310"/>
        <location filename="../src/common/actions.cpp" line="366"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="66"/>
        <location filename="../src/common/actions.cpp" line="138"/>
        <location filename="../src/common/actions.cpp" line="325"/>
        <source>Play Mode</source>
        <translation>播放模式</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="68"/>
        <location filename="../src/common/actions.cpp" line="140"/>
        <location filename="../src/common/actions.cpp" line="327"/>
        <source>Order Play</source>
        <translation>順序播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="69"/>
        <location filename="../src/common/actions.cpp" line="141"/>
        <location filename="../src/common/actions.cpp" line="328"/>
        <source>Shuffle Play</source>
        <translation>隨機播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="70"/>
        <location filename="../src/common/actions.cpp" line="142"/>
        <location filename="../src/common/actions.cpp" line="329"/>
        <source>Single Play</source>
        <translation>單個播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="71"/>
        <location filename="../src/common/actions.cpp" line="143"/>
        <location filename="../src/common/actions.cpp" line="330"/>
        <source>Single Loop</source>
        <translation>單曲循環</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="72"/>
        <location filename="../src/common/actions.cpp" line="144"/>
        <location filename="../src/common/actions.cpp" line="331"/>
        <source>List Loop</source>
        <translation>列表循環</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <location filename="../src/common/actions.cpp" line="164"/>
        <source>Frame</source>
        <translation>影格</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <location filename="../src/common/actions.cpp" line="166"/>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <location filename="../src/common/actions.cpp" line="173"/>
        <source>Clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="87"/>
        <location filename="../src/common/actions.cpp" line="174"/>
        <source>Counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="89"/>
        <location filename="../src/common/actions.cpp" line="176"/>
        <source>Next Frame</source>
        <translation>下一幀</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="90"/>
        <location filename="../src/common/actions.cpp" line="177"/>
        <source>Previous Frame</source>
        <translation>上一幀</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="99"/>
        <location filename="../src/common/actions.cpp" line="149"/>
        <location filename="../src/common/actions.cpp" line="336"/>
        <source>Playback Speed</source>
        <translation>倍速播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="101"/>
        <location filename="../src/common/actions.cpp" line="151"/>
        <location filename="../src/common/actions.cpp" line="338"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="102"/>
        <location filename="../src/common/actions.cpp" line="152"/>
        <location filename="../src/common/actions.cpp" line="339"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="103"/>
        <location filename="../src/common/actions.cpp" line="153"/>
        <location filename="../src/common/actions.cpp" line="340"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="104"/>
        <location filename="../src/common/actions.cpp" line="154"/>
        <location filename="../src/common/actions.cpp" line="341"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="105"/>
        <location filename="../src/common/actions.cpp" line="155"/>
        <location filename="../src/common/actions.cpp" line="342"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="129"/>
        <location filename="../src/common/actions.cpp" line="316"/>
        <source>Open URL</source>
        <translation>打開網址</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="130"/>
        <location filename="../src/common/actions.cpp" line="317"/>
        <source>Open CD/DVD</source>
        <translation>播放光盤</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="132"/>
        <location filename="../src/common/actions.cpp" line="319"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="133"/>
        <location filename="../src/common/actions.cpp" line="320"/>
        <source>Mini Mode</source>
        <translation>迷你模式</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="134"/>
        <location filename="../src/common/actions.cpp" line="321"/>
        <source>Always on Top</source>
        <translation>置頂窗口</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Sound</source>
        <translation>音效</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="191"/>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="194"/>
        <source>Stereo</source>
        <translation>立體聲</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="195"/>
        <source>Left channel</source>
        <translation>左聲道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="196"/>
        <source>Right channel</source>
        <translation>右聲道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="201"/>
        <location filename="../src/common/actions.cpp" line="424"/>
        <source>Track</source>
        <translation>音軌</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="216"/>
        <source>Load</source>
        <translation>載入字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="217"/>
        <source>Online Search</source>
        <translation>查找在線字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="221"/>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="225"/>
        <source>Hide</source>
        <translation>隱藏字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="228"/>
        <source>Encodings</source>
        <translation>編碼</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="295"/>
        <location filename="../src/common/actions.cpp" line="352"/>
        <source>Screenshot</source>
        <translation>截圖設定</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="298"/>
        <location filename="../src/common/actions.cpp" line="355"/>
        <source>Film Screenshot</source>
        <translation>影片截圖</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="299"/>
        <source>Burst Shooting</source>
        <translation>連拍截圖</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="300"/>
        <location filename="../src/common/actions.cpp" line="356"/>
        <source>Open screenshot folder</source>
        <translation>前往截圖文件夾</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <location filename="../src/common/actions.cpp" line="364"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="309"/>
        <location filename="../src/common/actions.cpp" line="365"/>
        <source>Film Info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="375"/>
        <source>Delete from playlist</source>
        <translation>從播放列表刪除</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="376"/>
        <source>Empty playlist</source>
        <translation>清空播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="377"/>
        <source>Display in file manager</source>
        <translation>在檔案管理員顯示</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="378"/>
        <source>Film info</source>
        <translation>影片訊息</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="44"/>
        <source>Duration: %1</source>
        <translation>時長：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Resolution: %1</source>
        <translation>解析度：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="54"/>
        <source>Size: %1</source>
        <translation>影片大小：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="77"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load successfully</source>
        <translation>載入字幕成功</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="2358"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load failed</source>
        <translation>載入字幕失敗</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1695"/>
        <location filename="../src/common/mainwindow.cpp" line="2685"/>
        <source>Cannot play the disc</source>
        <translation>無法播放光盤內容</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1712"/>
        <location filename="../src/common/mainwindow.cpp" line="3206"/>
        <source>Parse failed</source>
        <translation>解析失敗</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1720"/>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2092"/>
        <location filename="../src/common/mainwindow.cpp" line="2100"/>
        <location filename="../src/common/mainwindow.cpp" line="2108"/>
        <location filename="../src/common/mainwindow.cpp" line="2116"/>
        <location filename="../src/common/mainwindow.cpp" line="2124"/>
        <location filename="../src/common/mainwindow.cpp" line="2330"/>
        <location filename="../src/common/mainwindow.cpp" line="4409"/>
        <source>Speed: %1x</source>
        <translation>播放速度：%1倍</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2131"/>
        <source>Stereo</source>
        <translation>立體聲</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2136"/>
        <source>Left channel</source>
        <translation>左聲道</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2141"/>
        <source>Right channel</source>
        <translation>右聲道</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2246"/>
        <source>Track: %1</source>
        <translation>音軌：%1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2288"/>
        <location filename="../src/common/mainwindow.cpp" line="2305"/>
        <source>Unable to adjust the subtitle</source>
        <translation>當前字幕不可調節</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2293"/>
        <location filename="../src/common/mainwindow.cpp" line="2310"/>
        <source>Subtitle %1: %2s</source>
        <translation>字幕%1：%2秒</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>delayed</source>
        <translation>延遲</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>advanced</source>
        <translation>提前</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2452"/>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2461"/>
        <source>Film screenshot</source>
        <translation>影片截圖</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2462"/>
        <source>Saved to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2483"/>
        <location filename="../src/common/mainwindow.cpp" line="2611"/>
        <source>The screenshot is saved</source>
        <translation>截圖已保存</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2487"/>
        <location filename="../src/common/mainwindow.cpp" line="2615"/>
        <source>Failed to save the screenshot</source>
        <translation>截圖保存失敗</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2571"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>正在截圖，請稍候...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2690"/>
        <source>Reading DVD files...</source>
        <translation>正在讀取光盤文件...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4521"/>
        <source>Invalid file: %1</source>
        <translation>無效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4552"/>
        <source>Miracast disconnected</source>
        <translation>投屏已斷開</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2882"/>
        <source>No matching online subtitles</source>
        <translation>未找到匹配的在線字幕</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1756"/>
        <location filename="../src/common/mainwindow.cpp" line="1793"/>
        <source>All (*)</source>
        <translation>所有 (*)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2898"/>
        <source>4K video may be stuck</source>
        <translation>播放4K影片可能會出現卡頓</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2899"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2931"/>
        <location filename="../src/common/mainwindow.cpp" line="3855"/>
        <source>Order play</source>
        <translation>播放次序</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2934"/>
        <location filename="../src/common/mainwindow.cpp" line="3858"/>
        <source>Shuffle play</source>
        <translation>順序播放</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2937"/>
        <location filename="../src/common/mainwindow.cpp" line="3861"/>
        <source>Single play</source>
        <translation>單個播放</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2940"/>
        <location filename="../src/common/mainwindow.cpp" line="3864"/>
        <source>Single loop</source>
        <translation>單個循環</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2943"/>
        <location filename="../src/common/mainwindow.cpp" line="3867"/>
        <source>List loop</source>
        <translation>列表循環</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3097"/>
        <source>Buffering...</source>
        <translation>緩衝中...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3120"/>
        <location filename="../src/common/mainwindow.cpp" line="3145"/>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3122"/>
        <location filename="../src/common/mainwindow.cpp" line="3147"/>
        <source>Volume: %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3165"/>
        <location filename="../src/common/mainwindow.cpp" line="3197"/>
        <source>Cannot open file or stream</source>
        <translation>無法打開文件或者流</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4510"/>
        <source>The action is not supported in this video</source>
        <translation>當前影片不支持該功能</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4545"/>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3214"/>
        <location filename="../src/common/mainwindow.cpp" line="3219"/>
        <source>Invalid file</source>
        <translation>無效檔案</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2339"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3221"/>
        <source>Please insert a CD/DVD</source>
        <translation>請插入CD或DVD</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3226"/>
        <source>No video file found</source>
        <translation>沒有找到影片文件</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3846"/>
        <source>Please load the video first</source>
        <translation>請先載入影片</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3969"/>
        <location filename="../src/common/mainwindow.cpp" line="3977"/>
        <source>Please exit smart dock</source>
        <translation>Please exit smart dock</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4270"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD已彈出</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="243"/>
        <source>Film info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="295"/>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="296"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="297"/>
        <source>Duration</source>
        <translation>時長</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="302"/>
        <source>Path</source>
        <translation>保存路徑</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Codec info</source>
        <translation>編碼訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="328"/>
        <source>Video CodecID</source>
        <translation>影片流訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="329"/>
        <source>Video CodeRate</source>
        <translation>影片碼率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="275"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="288"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="276"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="289"/>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="330"/>
        <source>FPS</source>
        <translation>影片幀率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="278"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="331"/>
        <source>Proportion</source>
        <translation>顯示比例</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="279"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="332"/>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="337"/>
        <source>Audio info</source>
        <translation>音頻流訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>Audio CodecID</source>
        <translation>編碼樣式</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="359"/>
        <source>Audio CodeRate</source>
        <translation>編碼碼率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="360"/>
        <source>Audio digit</source>
        <translation>音頻位數</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="291"/>
        <source>%1 bits</source>
        <translation>%1 bits</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Channels</source>
        <translation>聲道數</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="292"/>
        <source>%1 channels</source>
        <translation>%1 聲道</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Sampling</source>
        <translation>採樣數</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="293"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="1744"/>
        <source>Internal</source>
        <translation>內部</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load successfully</source>
        <translation>載入字幕成功</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2400"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load failed</source>
        <translation>載入字幕失敗</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1755"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2736"/>
        <source>Cannot play the disc</source>
        <translation>無法播放光盤內容</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1772"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3224"/>
        <source>Parse failed</source>
        <translation>解析失敗</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1780"/>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1808"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1837"/>
        <source>All (*)</source>
        <translation>所有 (*)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2134"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2142"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2150"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2158"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2166"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2372"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4382"/>
        <source>Speed: %1x</source>
        <translation>播放速度：%1倍</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2173"/>
        <source>Stereo</source>
        <translation>立體聲</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2178"/>
        <source>Left channel</source>
        <translation>左聲道</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2183"/>
        <source>Right channel</source>
        <translation>右聲道</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2288"/>
        <source>Track: %1</source>
        <translation>音軌：%1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2330"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2347"/>
        <source>Unable to adjust the subtitle</source>
        <translation>當前字幕不可調節</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2335"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2352"/>
        <source>Subtitle %1: %2s</source>
        <translation>字幕%1：%2秒</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>delayed</source>
        <translation>延遲</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>advanced</source>
        <translation>提前</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2381"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2504"/>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2513"/>
        <source>Film screenshot</source>
        <translation>影片截圖</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2514"/>
        <source>Saved to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2535"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2662"/>
        <source>The screenshot is saved</source>
        <translation>截圖已保存</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2539"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2666"/>
        <source>Failed to save the screenshot</source>
        <translation>截圖保存失敗</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2623"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>正在截圖，請稍候...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2741"/>
        <source>Reading DVD files...</source>
        <translation>正在讀取光盤文件...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2913"/>
        <source>No matching online subtitles</source>
        <translation>未找到匹配的在線字幕</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2929"/>
        <source>4K video may be stuck</source>
        <translation>播放4K影片可能會出現卡頓</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2930"/>
        <source>OK</source>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2971"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3884"/>
        <source>Order play</source>
        <translation>播放次序</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2974"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3887"/>
        <source>Shuffle play</source>
        <translation>順序播放</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2977"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3890"/>
        <source>Single play</source>
        <translation>單個播放</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2980"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3893"/>
        <source>Single loop</source>
        <translation>單個循環</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2983"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3896"/>
        <source>List loop</source>
        <translation>列表循環</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3121"/>
        <source>Buffering...</source>
        <translation>緩衝中...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3144"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3169"/>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3146"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3171"/>
        <source>Volume: %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3215"/>
        <source>Cannot open file or stream</source>
        <translation>無法打開文件或者流</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3232"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3237"/>
        <source>Invalid file</source>
        <translation>無效檔案</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3239"/>
        <source>Please insert a CD/DVD</source>
        <translation>請插入CD或DVD</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3244"/>
        <source>No video file found</source>
        <translation>沒有找到影片文件</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3875"/>
        <source>Please load the video first</source>
        <translation>請先載入影片</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3995"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4002"/>
        <source>Please exit smart dock</source>
        <translation>Please exit smart dock</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4243"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD已彈出</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4483"/>
        <source>The action is not supported in this video</source>
        <translation>當前影片不支持該功能</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4494"/>
        <source>Invalid file: %1</source>
        <translation>無效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4518"/>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4525"/>
        <source>Miracast disconnected</source>
        <translation>投屏已斷開</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation>文件不存在</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation>%1個影片</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Play/Pause</source>
        <translation>暫停/繼續</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Previous</source>
        <translation>上一個</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1999"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2447"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2464"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <source>Miracast</source>
        <translation>投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1996"/>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2081"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2141"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation>文件不存在</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation>%1個影片</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="73"/>
        <source>Order play</source>
        <translation>播放次序</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="74"/>
        <source>Shuffle play</source>
        <translation>順序播放</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="75"/>
        <source>Single play</source>
        <translation>單個播放</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="76"/>
        <source>Single loop</source>
        <translation>單個循環</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="77"/>
        <source>List loop</source>
        <translation>列表循環</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="82"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="83"/>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="84"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="201"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/影院%2（%3）.jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <source>Play/Pause</source>
        <translation>暫停/繼續</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2573"/>
        <source>Previous</source>
        <translation>上一個</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2590"/>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2114"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2116"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2607"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2623"/>
        <source>Playlist</source>
        <translation>播放清單</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <source>Miracast</source>
        <translation>投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2108"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2110"/>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2204"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2206"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2269"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2271"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2558"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="18"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
</context>
</TS>
